Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(510)

Unified Diff: content/browser/fileapi/fileapi_message_filter.h

Issue 10870040: Rename FileSystemOperationInterface to FileSystemOperation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fixing Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/fileapi/fileapi_message_filter.h
diff --git a/content/browser/fileapi/fileapi_message_filter.h b/content/browser/fileapi/fileapi_message_filter.h
index dc2ab545944d9cb741dc1aa07bd8c89d814ea9c0..47b78aea0d9daee3ca62788b65ec41fbbd49457b 100644
--- a/content/browser/fileapi/fileapi_message_filter.h
+++ b/content/browser/fileapi/fileapi_message_filter.h
@@ -29,7 +29,7 @@ class Time;
namespace fileapi {
class FileSystemURL;
class FileSystemContext;
-class FileSystemOperationInterface;
+class FileSystemOperation;
}
namespace net {
@@ -170,8 +170,8 @@ class FileAPIMessageFilter : public content::BrowserMessageFilter {
int permissions,
base::PlatformFileError* error);
- // Creates a new FileSystemOperationInterface based on |target_url|.
- fileapi::FileSystemOperationInterface* GetNewOperation(
+ // Creates a new FileSystemOperation based on |target_url|.
+ fileapi::FileSystemOperation* GetNewOperation(
const fileapi::FileSystemURL& target_url,
int request_id);
@@ -180,7 +180,7 @@ class FileAPIMessageFilter : public content::BrowserMessageFilter {
fileapi::FileSystemContext* context_;
// Keeps ongoing file system operations.
- typedef IDMap<fileapi::FileSystemOperationInterface> OperationsMap;
+ typedef IDMap<fileapi::FileSystemOperation> OperationsMap;
OperationsMap operations_;
// The getter holds the context until Init() can be called from the
« no previous file with comments | « chrome/browser/extensions/api/downloads/downloads_api_unittest.cc ('k') | content/browser/fileapi/fileapi_message_filter.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698